/*
 * ContactDB.cs
 *
 * Database routines to work with Contact 
 * objects.
 */

using System;
using System.Data;
using System.Data.SqlClient;
using System.Collections;
using System.Configuration;

public class ContactDB {
    
    // helper method to get MS SQL Connection object.
    private static SqlConnection GetConnection(){
	    SqlConnection conn = 
            new SqlConnection(ConfigurationSettings.AppSettings.Get("dbconnectstr"));
        return conn;
    }

    // add a contact
    public static int AddContact(Contact c){
        SqlConnection conn = GetConnection();

        conn.Open();

        int id = 0;
        
        SqlCommand cmd = new SqlCommand("AddContact",conn);
        cmd.CommandType = CommandType.StoredProcedure;
        SqlParameter return_val = cmd.Parameters.Add("RETURN_VALUE",SqlDbType.Int);
        return_val.Direction = ParameterDirection.ReturnValue;

        SqlParameter param_fname = cmd.Parameters.Add("@fname",SqlDbType.VarChar);
        param_fname.Value = c.Fname;

        SqlParameter param_lname = cmd.Parameters.Add("@lname",SqlDbType.VarChar);
        param_lname.Value = c.Lname;

        SqlParameter param_email = cmd.Parameters.Add("@email",SqlDbType.VarChar);
        param_email.Value = c.Email;

        SqlParameter param_url = cmd.Parameters.Add("@url",SqlDbType.VarChar);
        param_url.Value = c.Url;

        SqlParameter param_phone = cmd.Parameters.Add("@phone",SqlDbType.VarChar);
        param_phone.Value = c.Phone;

        SqlParameter param_fax = cmd.Parameters.Add("@fax",SqlDbType.VarChar);
        param_fax.Value = c.Fax;

        SqlParameter param_street = cmd.Parameters.Add("@street",SqlDbType.VarChar);
        param_street.Value = c.Street;

        SqlParameter param_city = cmd.Parameters.Add("@city",SqlDbType.VarChar);
        param_city.Value = c.City;

        SqlParameter param_state = cmd.Parameters.Add("@state",SqlDbType.Char);
        param_state.Value = c.State;

        SqlParameter param_zip = cmd.Parameters.Add("@zip",SqlDbType.Char);
        param_zip.Value = c.Zip;

        cmd.ExecuteNonQuery();

        Int32 n = (Int32)cmd.Parameters["RETURN_VALUE"].Value;
        id = (int)n;

        conn.Close();

        return id;
    }

    // get a list of all contacts
    public static ArrayList GetContacts(){
        SqlConnection conn = GetConnection();

        conn.Open();
                
        SqlCommand cmd = new SqlCommand("ListContacts",conn);
        cmd.CommandType = CommandType.StoredProcedure;

        SqlDataReader r = cmd.ExecuteReader();
        ArrayList arr = new ArrayList();

        while(r.Read()){
            Contact c = new Contact();
            c.Id = (int)r.GetInt32(0);
            c.Fname = r.GetString(1);
            c.Lname = r.GetString(2);
            c.Email = r.GetString(3);
            c.Url = r.GetString(4);
            c.Phone = r.GetString(5);
            c.Fax = r.GetString(6);
            c.Street = r.GetString(7);
            c.City = r.GetString(8);
            c.State = r.GetString(9);
            c.Zip = r.GetString(10);
            arr.Add(c);
        }
        conn.Close();
        return arr;
    }


    // get a list of all contacts
    public static ArrayList FindContacts(string q){
        SqlConnection conn = GetConnection();

        conn.Open();
                
        SqlCommand cmd = new SqlCommand("FindContact",conn);
        cmd.CommandType = CommandType.StoredProcedure;

        SqlParameter param = cmd.Parameters.Add("@qstr",SqlDbType.VarChar);
        param.Value = q;

        SqlDataReader r = cmd.ExecuteReader();
        ArrayList arr = new ArrayList();

        while(r.Read()){
            Contact c = new Contact();
            c.Id = (int)r.GetInt32(0);
            c.Fname = r.GetString(1);
            c.Lname = r.GetString(2);
            c.Email = r.GetString(3);
            c.Url = r.GetString(4);
            c.Phone = r.GetString(5);
            c.Fax = r.GetString(6);
            c.Street = r.GetString(7);
            c.City = r.GetString(8);
            c.State = r.GetString(9);
            c.Zip = r.GetString(10);
            arr.Add(c);
        }
        conn.Close();
        return arr;
    }



    // get a list of all contacts
    public static Contact GetContact(int id){
        SqlConnection conn = GetConnection();

        conn.Open();
                
        SqlCommand cmd = new SqlCommand("GetContact",conn);
        cmd.CommandType = CommandType.StoredProcedure;

        SqlParameter param = cmd.Parameters.Add("@contactid",SqlDbType.Int);
        param.Value = id;

        SqlDataReader r = cmd.ExecuteReader();

        Contact c = null;
        if(r.Read()){
            c = new Contact();
            c.Id = (int)r.GetInt32(0);
            c.Fname = r.GetString(1);
            c.Lname = r.GetString(2);
            c.Email = r.GetString(3);
            c.Url = r.GetString(4);
            c.Phone = r.GetString(5);
            c.Fax = r.GetString(6);
            c.Street = r.GetString(7);
            c.City = r.GetString(8);
            c.State = r.GetString(9);
            c.Zip = r.GetString(10);
        }
        conn.Close();
        return c;
    }

    // get a list of all contacts
    public static void DeleteContact(int id){
        SqlConnection conn = GetConnection();
        conn.Open();
        SqlCommand cmd = new SqlCommand("DeleteContact",conn);
        cmd.CommandType = CommandType.StoredProcedure;
        SqlParameter param = cmd.Parameters.Add("@n",SqlDbType.Int);
        param.Value = id;
        cmd.ExecuteNonQuery();
        conn.Close();
    }


    // add a contact
    public static void UpdateContact(Contact c){
        SqlConnection conn = GetConnection();

        conn.Open();

        SqlCommand cmd = new SqlCommand("UpdateContact",conn);
        cmd.CommandType = CommandType.StoredProcedure;

        SqlParameter param_id = cmd.Parameters.Add("@id",SqlDbType.Int);
        param_id.Value = c.Id;

        SqlParameter param_fname = cmd.Parameters.Add("@fname",SqlDbType.VarChar);
        param_fname.Value = c.Fname;

        SqlParameter param_lname = cmd.Parameters.Add("@lname",SqlDbType.VarChar);
        param_lname.Value = c.Lname;

        SqlParameter param_email = cmd.Parameters.Add("@email",SqlDbType.VarChar);
        param_email.Value = c.Email;

        SqlParameter param_url = cmd.Parameters.Add("@url",SqlDbType.VarChar);
        param_url.Value = c.Url;

        SqlParameter param_phone = cmd.Parameters.Add("@phone",SqlDbType.VarChar);
        param_phone.Value = c.Phone;

        SqlParameter param_fax = cmd.Parameters.Add("@fax",SqlDbType.VarChar);
        param_fax.Value = c.Fax;

        SqlParameter param_street = cmd.Parameters.Add("@street",SqlDbType.VarChar);
        param_street.Value = c.Street;

        SqlParameter param_city = cmd.Parameters.Add("@city",SqlDbType.VarChar);
        param_city.Value = c.City;

        SqlParameter param_state = cmd.Parameters.Add("@state",SqlDbType.Char);
        param_state.Value = c.State;

        SqlParameter param_zip = cmd.Parameters.Add("@zip",SqlDbType.Char);
        param_zip.Value = c.Zip;

        cmd.ExecuteNonQuery();

        conn.Close();
    }

}

