/*
 * Main.cs
 *
 * Main command line program for the contacts
 * database.
 */

using System;
using System.Collections;

public class ConsoleApp {

    // helper function that prompts a user for a string.
    public static string AskForString(string prompt,string oldval){
        Console.Write(prompt);
        if(oldval != null && oldval.Length > 0)
            Console.Write(" ["+oldval+"]");
        Console.Write(": ");
        string s = Console.ReadLine();
        s = s.Trim();
        if(s.Length == 0)
            s = oldval;
        return s;
    }

    // helper method to prompt user to enter contact info.
    public static Contact GetContactFromUser(Contact old){
        Contact c = new Contact();
        c.Id = old.Id;
        c.Fname = AskForString("First Name",old.Fname);
        c.Lname = AskForString("Last Name",old.Lname);        
        c.Email = AskForString("E-Mail",old.Email);        
        c.Url = AskForString("WWW URL",old.Url);        
        c.Phone = AskForString("Phone",old.Phone);        
        c.Fax = AskForString("Fax",old.Fax);        
        c.Street = AskForString("Street",old.Street);        
        c.City = AskForString("City",old.City);        
        c.State = AskForString("State",old.State);        
        c.Zip = AskForString("Zip",old.Zip);
        return c;
    }

    // code to prompt the user for info
    public static void addcontact(){
        Console.WriteLine("Adding Contact:");
        Contact c = GetContactFromUser(new Contact());
        int n = ContactDB.AddContact(c);
        Console.WriteLine("Added Contact: "+n);        
    }

    // code to list contacts
    public static void listcontacts(){
        Console.WriteLine("All Contacts: ");
        ArrayList arr = ContactDB.GetContacts();
        for(int i=0;i<arr.Count;i++){
            Console.Write(arr[i]);
        }
    }

    // find contact
    public static void findcontacts(){
        Console.WriteLine("Search for Contact:");
        Console.Write("Query String: ");
        string q = Console.ReadLine();
        q = q.Trim();        
        ArrayList arr = ContactDB.FindContacts(q);
        if(arr.Count > 0){
            for(int i=0;i<arr.Count;i++){
                Console.Write(arr[i]);
            }
        }else{
            Console.WriteLine("No contacts found that match your query.");
        }        
    }

    // delete contacts
    public static void deletecontacts(){
        Console.WriteLine("Delete Contact:");
        Console.Write("Contact ID to Delete: ");
        string q = Console.ReadLine();
        q = q.Trim();
        Int32 n = Convert.ToInt32(q);
        Contact c = ContactDB.GetContact(n);
        if(c == null){
            Console.WriteLine("No contact with id="+n+" found.");
        }else{
            Console.WriteLine(""+c);
            Console.Write("Delete? yes/no: ");
            q = Console.ReadLine();
            if(q.Equals("yes"))
                ContactDB.DeleteContact(n);
        }
    }

    // update a contact
    public static void updatecontact(){
        Console.WriteLine("Update Contact:");
        Console.Write("Contact ID to Update: ");
        string q = Console.ReadLine();
        q = q.Trim();
        Int32 n = Convert.ToInt32(q);
        Contact c = ContactDB.GetContact(n);
        if(c == null){
            Console.WriteLine("No contact with id="+n+" found.");
        }else{
            Console.WriteLine("To leave an old value, just press Enter.");
            Contact cn = GetContactFromUser(c);
            Console.Write("Update? yes/no: ");
            q = Console.ReadLine();
            if(q.Equals("yes"))
                ContactDB.UpdateContact(cn);
        }
    }

    // main method with control loop
    public static void Main(string[] args){
        Console.WriteLine("Welcome to Contacts DB!");
        Console.WriteLine(" Tip: Type ``help'' for help.\n");

        Console.Write("> ");
        string line = Console.ReadLine();
        
        while(!line.Trim().Equals("exit")){

            line = line.Trim();

            if(line.Equals("list")){
                listcontacts();
            }else if(line.Equals("add")){
                addcontact();
            }else if(line.Equals("search")){
                findcontacts();
            }else if(line.Equals("update")){
                updatecontact();
            }else if(line.Equals("delete")){
                deletecontacts();
            }else if(line.Equals("help")){
                Console.WriteLine("possible commands are:");
                Console.WriteLine(" exit\tto exit the program.");
                Console.WriteLine(" add\tto add a contact.");
                Console.WriteLine(" list\tto list all contacts");
                Console.WriteLine(" delete\tto delete a contact.");
                Console.WriteLine(" search\tto find a contact.");
                Console.WriteLine(" update\tto update a contact.");
            }

            Console.Write("> ");
            line = Console.ReadLine();            
        }
    }
}