-- schema.sql

-- for use in Microsoft SQL Server 2000

-- schema for contacts application


CREATE DATABASE contacts
GO

-- username,password, dbname
sp_addlogin 'contacts','contacts','contacts'
GO

use contacts
GO

sp_changedbowner 'contacts'
GO

-- create a contacts table
CREATE TABLE Contact (
    [id] INT IDENTITY(1,1),
    [fname] VARCHAR(32),
    [lname] VARCHAR(32),
    [email] VARCHAR(64),
    [url] VARCHAR(128),
    [phone] VARCHAR(32),
    [fax] VARCHAR(32),
    [street] VARCHAR(64),
    [city] VARCHAR(32),
    [state] CHAR(2),
    [zip] CHAR(5),
    PRIMARY KEY([id])
)

GO

-- Retrieve all contacts alphabetically.
CREATE PROCEDURE ListContacts 
AS
 SELECT * 
 FROM Contact 
 ORDER BY lname,fname

GO

-- Add a new contact to database
CREATE PROCEDURE AddContact 
(   @fname VARCHAR(32),
    @lname VARCHAR(32),
    @email VARCHAR(64),
    @url VARCHAR(128),
    @phone VARCHAR(32),
    @fax VARCHAR(32),
    @street VARCHAR(64),
    @city VARCHAR(32),
    @state CHAR(2),
    @zip CHAR(5)
) AS 
 INSERT INTO Contact(fname,lname,email,
	url,phone,fax,street,city,
	state,zip) 
 VALUES (@fname,@lname,@email,
	@url,@phone,@fax,@street,@city,
	@state,@zip)
 RETURN @@IDENTITY

GO

-- look for a match in first name or last name.
CREATE PROCEDURE FindContact 
(
    @qstr VARCHAR(32)
) AS
 SELECT *
 FROM Contact
 WHERE fname like '%'+@qstr+'%' OR
       lname like '%'+@qstr+'%'

GO

-- Delete a record by id
CREATE PROCEDURE DeleteContact 
(
    @n INT
) AS
 DELETE FROM Contact
 WHERE [id] = @n

GO

-- Update the Contact record with all fields
CREATE PROCEDURE UpdateContact
(
    @id INT,
    @fname VARCHAR(32),
    @lname VARCHAR(32),
    @email VARCHAR(64),
    @url VARCHAR(128),
    @phone VARCHAR(32),
    @fax VARCHAR(32),
    @street VARCHAR(64),
    @city VARCHAR(32),
    @state CHAR(2),
    @zip CHAR(5)
) AS 
 UPDATE Contact SET
  [fname] = @fname,
  [lname] = @lname,
  [email] = @email,
  [url] = @url,
  [phone] = @phone,
  [fax] = @fax,
  [street] = @street,
  [city] = @city,
  [state] = @state,
  [zip] = @zip
 WHERE [id] = @id

GO

CREATE PROCEDURE GetContact
( @contactid INT )
AS
 SELECT * FROM Contact
 WHERE [id] = @contactid

GO
